==> krop-sqlite_3-0.9.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"sqlite","t":"sqlite","d":"","k":"static","x":""},
{"l":"krop/sqlite.html#","e":false,"i":"","n":"krop.sqlite","t":"krop.sqlite","d":"","k":"package","x":""},
{"l":"krop/sqlite/Sqlite.html#","e":false,"i":"","n":"Sqlite","t":"Sqlite","d":"krop.sqlite","k":"class","x":""},
{"l":"krop/sqlite/Sqlite.html#create-0","e":false,"i":"","n":"create","t":"create: Resource[IO, Transactor[IO]]","d":"krop.sqlite.Sqlite","k":"def","x":""},
{"l":"krop/sqlite/Sqlite$.html#","e":false,"i":"","n":"Sqlite","t":"Sqlite","d":"krop.sqlite","k":"object","x":""},
{"l":"krop/sqlite/Sqlite$.html#create-fffff08e","e":false,"i":"","n":"create","t":"create(filename: String): Resource[IO, Transactor[IO]]","d":"krop.sqlite.Sqlite","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats.html#","e":false,"i":"","n":"com.augustnagro.magnum.magcats","t":"com.augustnagro.magnum.magcats","d":"","k":"package","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor.html#","e":false,"i":"","n":"Transactor","t":"Transactor[F[_]]","d":"com.augustnagro.magnum.magcats","k":"class","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor.html#connect-5d3","e":false,"i":"","n":"connect","t":"connect[A](f: DbCon ?=> A): F[A]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor.html#transact-5d3","e":false,"i":"","n":"transact","t":"transact[A](f: DbTx ?=> A): F[A]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor.html#withConnectionConfig-fffff288","e":false,"i":"","n":"withConnectionConfig","t":"withConnectionConfig(connectionConfig: Connection => Unit): Transactor[F]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor.html#withSqlLogger-ee9","e":false,"i":"","n":"withSqlLogger","t":"withSqlLogger(sqlLogger: SqlLogger): Transactor[F]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#","e":false,"i":"","n":"Transactor","t":"Transactor","d":"com.augustnagro.magnum.magcats","k":"object","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#apply-fffffd9e","e":false,"i":"","n":"apply","t":"apply[F[_] : Async](dataSource: DataSource, sqlLogger: SqlLogger, connectionConfig: Connection => Unit, maxBlockingThreads: Int): F[Transactor[F]]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#apply-e53","e":false,"i":"","n":"apply","t":"apply[F[_] : Async](dataSource: DataSource, sqlLogger: SqlLogger, maxBlockingThreads: Int): F[Transactor[F]]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#apply-763","e":false,"i":"","n":"apply","t":"apply[F[_] : Async](dataSource: DataSource, maxBlockingThreads: Int): F[Transactor[F]]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#apply-fffffc40","e":false,"i":"","n":"apply","t":"apply[F[_] : Sync](dataSource: DataSource, sqlLogger: SqlLogger, connectionConfig: Connection => Unit): F[Transactor[F]]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#apply-fffffb35","e":false,"i":"","n":"apply","t":"apply[F[_] : Sync](dataSource: DataSource, sqlLogger: SqlLogger): F[Transactor[F]]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#apply-845","e":false,"i":"","n":"apply","t":"apply[F[_] : Sync](dataSource: DataSource): F[Transactor[F]]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""}];

==> krop-sqlite_3-0.9.1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"sqlite","t":"sqlite","d":"","k":"static","x":""},
{"l":"krop/sqlite.html#","e":false,"i":"","n":"krop.sqlite","t":"krop.sqlite","d":"","k":"package","x":""},
{"l":"krop/sqlite/Sqlite.html#","e":false,"i":"","n":"Sqlite","t":"Sqlite","d":"krop.sqlite","k":"class","x":""},
{"l":"krop/sqlite/Sqlite.html#create-0","e":false,"i":"","n":"create","t":"create: Resource[IO, Transactor[IO]]","d":"krop.sqlite.Sqlite","k":"def","x":""},
{"l":"krop/sqlite/Sqlite$.html#","e":false,"i":"","n":"Sqlite","t":"Sqlite","d":"krop.sqlite","k":"object","x":""},
{"l":"krop/sqlite/Sqlite$.html#create-fffff08e","e":false,"i":"","n":"create","t":"create(filename: String): Resource[IO, Transactor[IO]]","d":"krop.sqlite.Sqlite","k":"def","x":""},
{"l":"krop/sqlite/Sqlite$.html#create-fffff252","e":false,"i":"","n":"create","t":"create(filename: String, config: SQLiteConfig): Resource[IO, Transactor[IO]]","d":"krop.sqlite.Sqlite","k":"def","x":""},
{"l":"krop/sqlite/Sqlite$$config$.html#","e":false,"i":"","n":"config","t":"config","d":"krop.sqlite.Sqlite","k":"object","x":""},
{"l":"krop/sqlite/Sqlite$$config$.html#default-0","e":false,"i":"","n":"default","t":"default: SQLiteConfig","d":"krop.sqlite.Sqlite.config","k":"def","x":""},
{"l":"krop/sqlite/Sqlite$$config$.html#empty-0","e":false,"i":"","n":"empty","t":"empty: SQLiteConfig","d":"krop.sqlite.Sqlite.config","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats.html#","e":false,"i":"","n":"com.augustnagro.magnum.magcats","t":"com.augustnagro.magnum.magcats","d":"","k":"package","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor.html#","e":false,"i":"","n":"Transactor","t":"Transactor[F[_]]","d":"com.augustnagro.magnum.magcats","k":"class","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor.html#connect-5d3","e":false,"i":"","n":"connect","t":"connect[A](f: DbCon ?=> A): F[A]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor.html#transact-5d3","e":false,"i":"","n":"transact","t":"transact[A](f: DbTx ?=> A): F[A]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor.html#withConnectionConfig-fffff288","e":false,"i":"","n":"withConnectionConfig","t":"withConnectionConfig(connectionConfig: Connection => Unit): Transactor[F]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor.html#withSqlLogger-ee9","e":false,"i":"","n":"withSqlLogger","t":"withSqlLogger(sqlLogger: SqlLogger): Transactor[F]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#","e":false,"i":"","n":"Transactor","t":"Transactor","d":"com.augustnagro.magnum.magcats","k":"object","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#apply-fffffd9e","e":false,"i":"","n":"apply","t":"apply[F[_] : Async](dataSource: DataSource, sqlLogger: SqlLogger, connectionConfig: Connection => Unit, maxBlockingThreads: Int): F[Transactor[F]]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#apply-e53","e":false,"i":"","n":"apply","t":"apply[F[_] : Async](dataSource: DataSource, sqlLogger: SqlLogger, maxBlockingThreads: Int): F[Transactor[F]]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#apply-763","e":false,"i":"","n":"apply","t":"apply[F[_] : Async](dataSource: DataSource, maxBlockingThreads: Int): F[Transactor[F]]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#apply-fffffc40","e":false,"i":"","n":"apply","t":"apply[F[_] : Sync](dataSource: DataSource, sqlLogger: SqlLogger, connectionConfig: Connection => Unit): F[Transactor[F]]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#apply-fffffb35","e":false,"i":"","n":"apply","t":"apply[F[_] : Sync](dataSource: DataSource, sqlLogger: SqlLogger): F[Transactor[F]]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""},
{"l":"com/augustnagro/magnum/magcats/Transactor$.html#apply-845","e":false,"i":"","n":"apply","t":"apply[F[_] : Sync](dataSource: DataSource): F[Transactor[F]]","d":"com.augustnagro.magnum.magcats.Transactor","k":"def","x":""}];
